@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 //We need to include this before anything else, to avoid redefinitions:
@@ -66,7 +66,7 @@ boost::python::object PyGlomRecord::get_connection()
   {
     if(!_PyGObject_API)
     {
-      std::cerr << "pyggobject does not seem to be initialized properly." << std::endl;
+      std::cerr << G_STRFUNC << ": pyggobject does not seem to be initialized properly." << std::endl;
       return result;
     }
 
@@ -130,7 +130,7 @@ void PyGlomRecord::setitem(const boost::python::object& key, const boost::python
 {
   if(m_read_only)
   {
-    std::cerr << "PyGlomRecord::setitem(): Failed to set a value because the record object is read-only."<< std::endl;
+    std::cerr << G_STRFUNC << ": PyGlomRecord::setitem(): Failed to set a value because the record object is read-only."<< std::endl;
     return;
   }
   //Get the specified field name (and details) and value:
